summaryrefslogtreecommitdiffstats
path: root/libkdeedu/kdeeduplot/kplotaxis.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-07-31 19:39:55 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-07-31 19:39:55 +0000
commit0a6e0958c03e41c87b15557b6f407874f20c2f8d (patch)
tree2cdd58c4013b1be09cfcbb4ddae2b05712b9aeee /libkdeedu/kdeeduplot/kplotaxis.h
parent83f9dfafc157ff7823804b3ff457b43d021a5b4b (diff)
downloadtdeedu-0a6e0958c03e41c87b15557b6f407874f20c2f8d.tar.gz
tdeedu-0a6e0958c03e41c87b15557b6f407874f20c2f8d.zip
Trinity Qt initial conversion
git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdeedu@1157642 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'libkdeedu/kdeeduplot/kplotaxis.h')
-rw-r--r--libkdeedu/kdeeduplot/kplotaxis.h16
1 files changed, 8 insertions, 8 deletions
diff --git a/libkdeedu/kdeeduplot/kplotaxis.h b/libkdeedu/kdeeduplot/kplotaxis.h
index 3a82417c..107620b8 100644
--- a/libkdeedu/kdeeduplot/kplotaxis.h
+++ b/libkdeedu/kdeeduplot/kplotaxis.h
@@ -18,7 +18,7 @@
#ifndef KPLOTAXIS_H
#define KPLOTAXIS_H
-#include <qstring.h>
+#include <tqstring.h>
#include <kdemacros.h>
@@ -34,7 +34,7 @@ public:
KPlotAxis();
/**@short Constructor, constructs a labeled axis. */
- KPlotAxis(const QString& label);
+ KPlotAxis(const TQString& label);
/**@short Destructor. */
virtual ~KPlotAxis() {}
@@ -55,12 +55,12 @@ public:
*@param label A short string describing the data plotted on the axis.
*Set the label to an empty string to omit the axis label.
*/
- virtual void setLabel( const QString& label ) { m_label = label; }
+ virtual void setLabel( const TQString& label ) { m_label = label; }
/**@short Returns the axis label. */
- virtual QString label() const { return m_label; }
+ virtual TQString label() const { return m_label; }
- /**@short Set the number format for the tick labels, see QString::arg() for
+ /**@short Set the number format for the tick labels, see TQString::arg() for
description of arguments.
*/
virtual void setLabelFormat(int fieldWidth, char fmt = 'g', int prec=-1) {
@@ -78,9 +78,9 @@ public:
private:
bool m_visible; ///< Property "visible" defines if Axis is drawn or not.
QString m_label; ///< The label of the axis.
- int m_labelFieldWidth; ///< Field width for number labels, see QString::arg().
- char m_labelFmt; ///< Number format for number labels, see QString::arg().
- int m_labelPrec; ///< Number precision for number labels, see QString::arg().
+ int m_labelFieldWidth; ///< Field width for number labels, see TQString::arg().
+ char m_labelFmt; ///< Number format for number labels, see TQString::arg().
+ int m_labelPrec; ///< Number precision for number labels, see TQString::arg().
};
#endif // KPLOTAXIS_H